==> libopenshot-audio-docs-0.3.2-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/search/variables_1.js <==
var searchData=
[
  ['bitspersample_0',['bitsPerSample',['../classjuce_1_1AudioFormatReader.html#acc3c8af71a17b9ad06c0e44a47fcee5c',1,'juce::AudioFormatReader::bitsPerSample()'],['../classjuce_1_1AudioFormatWriter.html#a3d60969bc178245e1d656e49aff54b21',1,'juce::AudioFormatWriter::bitsPerSample()']]],
  ['bpm_1',['bpm',['../structjuce_1_1AudioPlayHead_1_1CurrentPositionInfo.html#a928dfbf707b4a94f34dfd818ef379636',1,'juce::AudioPlayHead::CurrentPositionInfo']]],
  ['buffer_2',['buffer',['../structjuce_1_1AudioSourceChannelInfo.html#a98ec39aa072305634595929687d2d9c8',1,'juce::AudioSourceChannelInfo']]],
  ['buffersize_3',['bufferSize',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#ab839c8166e730ddea4dfd6b9d13c493d',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['bwavcodinghistory_4',['bwavCodingHistory',['../classjuce_1_1WavAudioFormat.html#a0756f0e0786eae9d10b76b094c006c82',1,'juce::WavAudioFormat']]],
  ['bwavdescription_5',['bwavDescription',['../classjuce_1_1WavAudioFormat.html#ab047b2ab28b0809a99b33324e4f4d5ce',1,'juce::WavAudioFormat']]],
  ['bwavoriginationdate_6',['bwavOriginationDate',['../classjuce_1_1WavAudioFormat.html#aa94df89a3b3cd60f1cc25c500cc5a0ea',1,'juce::WavAudioFormat']]],
  ['bwavoriginationtime_7',['bwavOriginationTime',['../classjuce_1_1WavAudioFormat.html#ac46188e7734a5b8bce390cae279749a8',1,'juce::WavAudioFormat']]],
  ['bwavoriginator_8',['bwavOriginator',['../classjuce_1_1WavAudioFormat.html#afa5ecbd9a3a8df8d1df58198f6ff9130',1,'juce::WavAudioFormat']]],
  ['bwavoriginatorref_9',['bwavOriginatorRef',['../classjuce_1_1WavAudioFormat.html#a5abaaeb22ee012863ffdea5a1b99fd9a',1,'juce::WavAudioFormat']]],
  ['bwavtimereference_10',['bwavTimeReference',['../classjuce_1_1WavAudioFormat.html#a07e729f2acc7d9c12b4ae83eea06bdf6',1,'juce::WavAudioFormat']]]
];

==> libopenshot-audio-docs-0.4.0-1-aarch64.pkg.tar.xz: usr/share/doc/OpenShotAudio/API/search/variables_1.js <==
var searchData=
[
  ['bitspersample_0',['bitsPerSample',['../classjuce_1_1AudioFormatReader.html#acc3c8af71a17b9ad06c0e44a47fcee5c',1,'juce::AudioFormatReader::bitsPerSample'],['../classjuce_1_1AudioFormatWriter.html#a3d60969bc178245e1d656e49aff54b21',1,'juce::AudioFormatWriter::bitsPerSample']]],
  ['bpm_1',['bpm',['../structjuce_1_1AudioPlayHead_1_1CurrentPositionInfo.html#a928dfbf707b4a94f34dfd818ef379636',1,'juce::AudioPlayHead::CurrentPositionInfo']]],
  ['buffer_2',['buffer',['../structjuce_1_1AudioSourceChannelInfo.html#a98ec39aa072305634595929687d2d9c8',1,'juce::AudioSourceChannelInfo']]],
  ['buffersize_3',['bufferSize',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#ab839c8166e730ddea4dfd6b9d13c493d',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
  ['bwavcodinghistory_4',['bwavCodingHistory',['../classjuce_1_1WavAudioFormat.html#a0756f0e0786eae9d10b76b094c006c82',1,'juce::WavAudioFormat']]],
  ['bwavdescription_5',['bwavDescription',['../classjuce_1_1WavAudioFormat.html#ab047b2ab28b0809a99b33324e4f4d5ce',1,'juce::WavAudioFormat']]],
  ['bwavoriginationdate_6',['bwavOriginationDate',['../classjuce_1_1WavAudioFormat.html#aa94df89a3b3cd60f1cc25c500cc5a0ea',1,'juce::WavAudioFormat']]],
  ['bwavoriginationtime_7',['bwavOriginationTime',['../classjuce_1_1WavAudioFormat.html#ac46188e7734a5b8bce390cae279749a8',1,'juce::WavAudioFormat']]],
  ['bwavoriginator_8',['bwavOriginator',['../classjuce_1_1WavAudioFormat.html#afa5ecbd9a3a8df8d1df58198f6ff9130',1,'juce::WavAudioFormat']]],
  ['bwavoriginatorref_9',['bwavOriginatorRef',['../classjuce_1_1WavAudioFormat.html#a5abaaeb22ee012863ffdea5a1b99fd9a',1,'juce::WavAudioFormat']]],
  ['bwavtimereference_10',['bwavTimeReference',['../classjuce_1_1WavAudioFormat.html#a07e729f2acc7d9c12b4ae83eea06bdf6',1,'juce::WavAudioFormat']]]
];
